import { useEffect, useMemo } from 'react';
import { isBrowser } from './utils';
import defaultSettings from '../defaultSettings';
import { useMediaQuery } from 'react-responsive';
export function useDocumentTitle(titleInfo) {
  var appDefaultTitle = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : defaultSettings.title;
  var titleText = typeof titleInfo.pageName === 'string' ? titleInfo.title : appDefaultTitle;
  useEffect(function () {
    if (isBrowser() && titleText) {
      document.title = titleText;
    }
  }, [titleInfo.title]);
}
export var MediaQueryEnum = {
  xs: {
    maxWidth: 575
  },
  sm: {
    minWidth: 576,
    maxWidth: 767
  },
  md: {
    minWidth: 768,
    maxWidth: 991
  },
  lg: {
    minWidth: 992,
    maxWidth: 1199
  },
  xl: {
    minWidth: 1200,
    maxWidth: 1599
  },
  xxl: {
    minWidth: 1600
  }
};
export var useAntdMediaQuery = function useAntdMediaQuery() {
  var isMd = useMediaQuery(MediaQueryEnum.md);
  var isLg = useMediaQuery(MediaQueryEnum.lg);
  var isXxl = useMediaQuery(MediaQueryEnum.xxl);
  var isXl = useMediaQuery(MediaQueryEnum.xl);
  var isSm = useMediaQuery(MediaQueryEnum.sm);
  var isXs = useMediaQuery(MediaQueryEnum.xs);

  var calculateColSpan = function calculateColSpan() {
    if (isXxl) {
      return 'xxl';
    }

    if (isXl) {
      return 'xl';
    }

    if (isLg) {
      return 'lg';
    }

    if (isMd) {
      return 'md';
    }

    if (isSm) {
      return 'sm';
    }

    if (isXs) {
      return 'xs';
    }

    return 'md';
  };

  var colSpan = useMemo(calculateColSpan, [isMd, isLg, isXxl, isXl, isSm, isXs]);
  return colSpan;
};