"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useDocumentTitle = useDocumentTitle;
exports.useAntdMediaQuery = exports.MediaQueryEnum = void 0;

var _react = require("react");

var _utils = require("./utils");

var _defaultSettings = _interopRequireDefault(require("../defaultSettings"));

var _reactResponsive = require("react-responsive");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function useDocumentTitle(titleInfo) {
  var appDefaultTitle = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : _defaultSettings.default.title;
  var titleText = typeof titleInfo.pageName === 'string' ? titleInfo.title : appDefaultTitle;
  (0, _react.useEffect)(function () {
    if ((0, _utils.isBrowser)() && titleText) {
      document.title = titleText;
    }
  }, [titleInfo.title]);
}

var MediaQueryEnum = {
  xs: {
    maxWidth: 575
  },
  sm: {
    minWidth: 576,
    maxWidth: 767
  },
  md: {
    minWidth: 768,
    maxWidth: 991
  },
  lg: {
    minWidth: 992,
    maxWidth: 1199
  },
  xl: {
    minWidth: 1200,
    maxWidth: 1599
  },
  xxl: {
    minWidth: 1600
  }
};
exports.MediaQueryEnum = MediaQueryEnum;

var useAntdMediaQuery = function useAntdMediaQuery() {
  var isMd = (0, _reactResponsive.useMediaQuery)(MediaQueryEnum.md);
  var isLg = (0, _reactResponsive.useMediaQuery)(MediaQueryEnum.lg);
  var isXxl = (0, _reactResponsive.useMediaQuery)(MediaQueryEnum.xxl);
  var isXl = (0, _reactResponsive.useMediaQuery)(MediaQueryEnum.xl);
  var isSm = (0, _reactResponsive.useMediaQuery)(MediaQueryEnum.sm);
  var isXs = (0, _reactResponsive.useMediaQuery)(MediaQueryEnum.xs);

  var calculateColSpan = function calculateColSpan() {
    if (isXxl) {
      return 'xxl';
    }

    if (isXl) {
      return 'xl';
    }

    if (isLg) {
      return 'lg';
    }

    if (isMd) {
      return 'md';
    }

    if (isSm) {
      return 'sm';
    }

    if (isXs) {
      return 'xs';
    }

    return 'md';
  };

  var colSpan = (0, _react.useMemo)(calculateColSpan, [isMd, isLg, isXxl, isXl, isSm, isXs]);
  return colSpan;
};

exports.useAntdMediaQuery = useAntdMediaQuery;